@@ -128,6 +128,7 @@ pub trait MutStats {
 pub trait Vecg<_T,U> {
     /// Scalar multiplication of a vector
     fn smult(self, s:U) -> Vec<f64>;
+    /// Scalar multiplication by f64
     fn smultf64(self, s:f64) -> Vec<f64>;
     /// Scalar addition to vector
     fn sadd(self, s:U) -> Vec<f64>;
@@ -135,16 +136,19 @@ pub trait Vecg<_T,U> {
     fn dotp(self, v:&[U]) -> f64;
     /// Cosine of angle between two slices
     fn cosine(self, v:&[U]) -> f64;
-    /// Vectors' difference
+    /// Vectors' subtraction (difference)
     fn vsub(self, v:&[U]) -> Vec<f64>;
+    /// Vector subtraction of `&[f64]`
     fn vsubf64(self, v:&[f64]) -> Vec<f64>;
     /// Vectors difference as unit vector (done together for efficiency)
     fn vsubunit(self, v: &[U]) -> Vec<f64>; 
     /// Vector addition
-    fn vadd(self, v:&[U]) -> Vec<f64>;  
+    fn vadd(self, v:&[U]) -> Vec<f64>; 
+    /// Adding `&[f64]` 
     fn vaddf64(self, v:&[f64]) -> Vec<f64>; 
     /// Euclidian distance 
     fn vdist(self, v:&[U]) -> f64;
+    /// Euclidian distance to `&[f64]`
     fn vdistf64(self, v:&[f64]) -> f64;
     /// Euclidian distance squared
     fn vdistsq(self, v:&[U]) -> f64; 
@@ -188,6 +192,7 @@ pub trait MutVecg<U> {
     /// mutable vector addition
     fn mvadd(self, _v: &[U]);  
 }
+/// Vector mutating operations that take one argument of f64 end type.
 pub trait MutVecf64 {
     /// mutable multiplication by a scalar
     fn mutsmult(self, _s:f64); 
@@ -197,7 +202,7 @@ pub trait MutVecf64 {
     fn mutvadd(self, _v: &[f64]); 
 }
 
-/// Methods specialised to, or more efficient for, `&[u8]`
+/// Methods specialised to, or more efficient for `&[u8]`
 pub trait Vecu8 {
     /// Scalar product of two (positive) u8 slices.   
     /// Must be of the same length - no error checking (for speed)
@@ -232,7 +237,7 @@ pub trait Vecu8 {
     fn dependenceu8(self, v:&[u8]) -> f64;
 }
 
-/// Some support for self argument of `Vec<Vec<u8>>` type (vector of vectors of bytes)
+/// A few specialised methods applicable to `Vec<Vec<u8>>` (vector of vectors of bytes).
 pub trait VecVecu8 { 
     /// Centroid = euclidian mean of a set of points  
     fn acentroid(self) -> Vec<f64>;
@@ -251,7 +256,7 @@ pub trait VecVecu8 {
     fn wcovar(self, ws:&[u8], m:&[f64]) -> Vec<f64>;
 }
 
-/// Methods applicable to vector of vectors of `<f64>`
+/// Methods applicable to vector of vectors of generic end type
 pub trait VecVec<T> {
 
     /// Arithmetic Centre = euclidian mean of a set of points
@@ -319,6 +324,10 @@ pub trait VecVec<T> {
     fn wgmedian(self, ws: &[T],eps: f64) -> Vec<f64>; 
     /// Flattened lower triangular part of a covariance matrix of a Vec of f64 vectors.
     fn covar(self, med:&[f64]) -> Vec<f64>; 
+    /// Flattened lower triangular part of a comediance matrix of a Vec of f64 vectors.
+    fn comed(self, m:&[f64], eps:f64) -> Vec<f64>;
     /// Flattened lower triangular part of a covariance matrix for weighted f64 vectors.
     fn wcovar(self, ws:&[f64], m:&[f64]) -> Vec<f64>;
+    /// Flattened lower triangular part of a comediance matrix for weighted f64 vectors.
+    fn wcomed(self, ws:&[f64], m:&[f64], eps:f64) -> Vec<f64>;
 }
